@@ -13,3 +13,8 @@ from .sasoa import SASOA
 # BO Support functions import
 #############################
 from .bo import parse_dfx
+
+#############################
+# Win task parser
+#############################
+from .taskparser import XMLScheduledTask
