@@ -13,6 +13,7 @@ from .globals import all_obj_types
 from sys import platform
 from requests.exceptions import ConnectionError
 
+logging.getLogger(__name__)
 
 if platform == "linux" or platform == "linux2":
     from .globals import java_linux as java
@@ -137,7 +138,7 @@ sasconnection = {{'java'      : '{java}',
     return sas
 
 
-def get_objects_from_spk(spk_path: str, log_path: str, object_types: list = None):
+def get_objects_from_spk(spk_path: str, log_path: str = None, object_types: list = None) -> dict:
     """
     Extracts information about metadata objects from spk
     :param spk_path: path (str) to spk
@@ -152,7 +153,7 @@ def get_objects_from_spk(spk_path: str, log_path: str, object_types: list = None
     """
     logging.info(f"Object extraction from {spk_path} started.")
     log_lines = []
-    validation_status = False
+    success_status = False
     if not object_types:
         object_types = all_obj_types
     extracted_objects = {i: [] for i in object_types}
@@ -169,19 +170,22 @@ def get_objects_from_spk(spk_path: str, log_path: str, object_types: list = None
                     extracted_objects[obj_type].append(obj_path)
                     logging.debug(f"Founded object {obj_type} in {obj_path}")
                     log_lines += f"Extracted object {obj_type}: {obj_path}\n"
-            validation_status = True
+            success_status = True
             logging.info(f"List of objects extracted successfully.")
     except Exception as e:
         logging.error(f"Errors during extraction: {str(e)}")
         log_lines += str(e)
     finally:
         logging.debug(f"Writing log to {log_path}")
-        with open(log_path, 'a') as logfile:
-            logfile.writelines(log_lines)
-        return {'Success': validation_status, 'Objects': extracted_objects}
+        if log_path:
+            with open(log_path, 'a') as logfile:
+                logfile.writelines(log_lines)
+        return {'Success': success_status, 'Objects': extracted_objects}
 
 
-def check_sas_code(sas_script_path, log_path):
+def check_sas_code(sas_script_path: str = None,
+                   sas_script:str = None,
+                   log_path: str = None) -> dict:
     """
     Sas code checking. Implements various sas scripth checks
     (drop database includes, etc.)
@@ -193,10 +197,18 @@ def check_sas_code(sas_script_path, log_path):
     validation_log_lines = []
     validation_status = False
     try:
-        with open(sas_script_path, 'r') as script:
-            validation_log_lines += 'Validated\n'
-            validation_status = True
-            logging.info(f"Script validated successfully.")
+        if sas_script_path:
+            with open(sas_script_path, 'r') as f:
+                sas_script = f.read()
+                ### checks....
+                pass
+        elif sas_script:
+            pass
+        else:
+            raise ValueError
+        validation_log_lines += 'Validated\n'
+        validation_status = True
+        logging.info(f"Script validated successfully.")
     except Exception as e:
         validation_log_lines += str(e)
         logging.critical(f"Script did not passed validation.")
@@ -259,7 +271,9 @@ def import_spk(sas_conn_file_path, spk_path, log_path, import_package_jar_path,
         return {'Success': execution_status, 'Warnings': warnings}
 
 
-def check_import(sas_conn_file_path, spk_path, import_package_jar_path,
+def check_import(sas_conn_file_path,
+                 spk_path,
+                 import_package_jar_path,
                  log_path,
                  target='/'):
     """
@@ -285,46 +299,84 @@ def check_import(sas_conn_file_path, spk_path, import_package_jar_path,
                               import_package_jar_path=import_package_jar_path,
                               safe_mode=True)
     return check_result
+#
+#
+# def launch_sas_code(sas_script_path, sasobjsp_host, sasobjsp_port, sasobjsp_user, sasobjsp_pass,
+#                     log_path):
+#     """
+#     Opens sas session and launches code, also saves results to log.
+#     :param sas_script_path: path to file, that contains sas script (.sas)
+#     :param saspy_cfg_file_path: path to pycfg file, which contains saspy
+#     connection descriptor.
+#     :param user: user for sas app server
+#     :param password: password for sas app server
+#     (can be encrypted in sas form, like {001}WDBAYDVWDVW)
+#     :param log_path: path (str) to execution log file
+#     :return: dict with key 'Success', indicating the success of code execution
+#     """
+#     logging.info(f"Launching of script {sas_script_path} started.")
+#     saspy_conn = tempfile.NamedTemporaryFile(mode='w+', delete=True)
+#     saspy_conn.write(f"""SAS_config_names=['sasconnection']
+# SAS_config_options = {{'lock_down': False,
+#                     'verbose'  : True,
+#                     'prompt'   : True
+#                     }}
+# SAS_output_options = {{'output' : 'html5'}}
+# sasconnection = {{'java'      : '/usr/bin/java',
+#             'iomhost'   : ['{sasobjsp_host}'],
+#             'iomport'   : {sasobjsp_port},
+#             'encoding': 'cyrillic',
+#             'options' : ["-fullstimer"]
+#             }}""")
+#     saspy_conn.seek(0)
+#     execution_log_lines = []
+#     execution_status = False
+#     try:
+#         with open(sas_script_path, 'r') as sas_script:
+#             command = sas_script.read()
+#             execution_log_lines += 'The following script obtained from file:\n'
+#             execution_log_lines += command
+#         sas = saspy.SASsession(cfgfile=saspy_conn.name, omruser=sasobjsp_user,
+#                                omrpw=sasobjsp_pass)
+#         code = sas.submit(command)
+#         sas.endsas()
+#         execution_log_lines += code['LOG']
+#         execution_status = True
+#     except Exception as e:
+#         logging.error(f"Error while executing script. {str(e)}")
+#         execution_log_lines += str(e)
+#     finally:
+#         logging.info(f"Log will be written to {log_path}")
+#         with open(log_path, 'a') as log:
+#             log.writelines(execution_log_lines)
+#         return {'Success': execution_status}
+#
 
 
-def launch_sas_code(sas_script_path, sasobjsp_host, sasobjsp_port, sasobjsp_user, sasobjsp_pass,
-                    log_path):
-    """
-    Opens sas session and launches code, also saves results to log.
-    :param sas_script_path: path to file, that contains sas script (.sas)
-    :param saspy_cfg_file_path: path to pycfg file, which contains saspy
-    connection descriptor.
-    :param user: user for sas app server
-    :param password: password for sas app server
-    (can be encrypted in sas form, like {001}WDBAYDVWDVW)
-    :param log_path: path (str) to execution log file
-    :return: dict with key 'Success', indicating the success of code execution
-    """
-    logging.info(f"Launching of script {sas_script_path} started.")
-    saspy_conn = tempfile.NamedTemporaryFile(mode='w+', delete=True)
-    saspy_conn.write(f"""SAS_config_names=['sasconnection']
-SAS_config_options = {{'lock_down': False,
-                    'verbose'  : True,
-                    'prompt'   : True
-                    }}
-SAS_output_options = {{'output' : 'html5'}} 
-sasconnection = {{'java'      : '/usr/bin/java',
-            'iomhost'   : ['{sasobjsp_host}'],
-            'iomport'   : {sasobjsp_port},
-            'encoding': 'cyrillic',
-            'options' : ["-fullstimer"]
-            }}""")
-    saspy_conn.seek(0)
-    execution_log_lines = []
+def launch_sas_code(sasobjsp_host: str,
+                    sasobjsp_port: str,
+                    sasobjsp_user: str,
+                    sasobjsp_pass: str,
+                    sas_script: str = None,
+                    sas_script_path: str = None,
+                    sas_appserver: str = 'SASApp - Workspace Server',
+                    log_path: str = None):
+    if sas_script and sas_script_path:
+        logging.error(f"You cannot specify 'sas script' an 'sas_script_path' simultaneously")
+        raise SyntaxError
     execution_status = False
+    execution_log_lines = []
     try:
-        with open(sas_script_path, 'r') as sas_script:
-            command = sas_script.read()
-            execution_log_lines += 'The following script obtained from file:\n'
-            execution_log_lines += command
-        sas = saspy.SASsession(cfgfile=saspy_conn.name, omruser=sasobjsp_user,
-                               omrpw=sasobjsp_pass)
-        code = sas.submit(command)
+        if sas_script_path:
+            logging.info(f"Launching of script {sas_script_path} started.")
+            with open(sas_script_path, 'r') as f:
+                sas_script = f.read()
+                execution_log_lines += 'The following script obtained from file:\n'
+                execution_log_lines += sas_script
+        logging.info(f"Starting sas session...")
+        sas = AbstractSAS(sasobjsp_user=sasobjsp_user, sasobjsp_pass=sasobjsp_pass,
+                          sasobjsp_host=sasobjsp_host, sasobjsp_port=sasobjsp_port, appserver=sas_appserver)
+        code = sas.submit(sas_script)
         sas.endsas()
         execution_log_lines += code['LOG']
         execution_status = True
@@ -333,8 +385,9 @@ sasconnection = {{'java'      : '/usr/bin/java',
         execution_log_lines += str(e)
     finally:
         logging.info(f"Log will be written to {log_path}")
-        with open(log_path, 'a') as log:
-            log.writelines(execution_log_lines)
+        if log_path:
+            with open(log_path, 'a') as log:
+                log.writelines(execution_log_lines)
         return {'Success': execution_status}
 
 
